==> estateplat-common-1.2.3-20180705.010641-136-sources.jar: cn/gtmap/estateplat/model/server/core/GdTd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 *过渡期土地登记信息表
 * @author lst
 * @version V1.0, 15-3-23
 */
@Table(name = "gd_td")
public class GdTd implements Serializable, InsertVo {
    @Id
    private String tdid;//主键
    private String djh;//地籍号
    private String zl;//土地坐落
    private Double zdmj;//宗地面积
    private String yt;//用途
    private String qsxz;//权属性质
    private String syqlx;//使用权类型
    private String qlsdfs;//权利设定方式
    private Double rjl;//容积率
    private Double jzmj;//建筑密度
    private Double jzxg;//建筑限高
    private String zdsz;//宗地四至
	private String gyqk;//共有情况
    private Double qdjg;//取得价格
    private String dwdm;//单位代码
    private Double tdjg;//土地价格
    private String dw;//单位
    private String sjly;//数据来源
    private String ldjh;//老地籍号
    private String qsrq;//起始日期
    private String zzrq;//终止日期

	private Date gxrq;

	public String getSjly() {
		return sjly;
	}

	public void setSjly(String sjly) {
		this.sjly = sjly;
	}

	public String getLdjh() {
		return ldjh;
	}

	public void setLdjh(String ldjh) {
		this.ldjh = ldjh;
	}

	public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}

	public String getTdid() {
        return tdid;
    }

    public void setTdid(String tdid) {
        this.tdid = tdid;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getSyqlx() {
        return syqlx;
    }

    public void setSyqlx(String syqlx) {
        this.syqlx = syqlx;
    }

    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    public Double getRjl() {
        return rjl;
    }

    public void setRjl(Double rjl) {
        this.rjl = rjl;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getJzxg() {
        return jzxg;
    }

    public void setJzxg(Double jzxg) {
        this.jzxg = jzxg;
    }

    public String getZdsz() {
        return zdsz;
    }

    public void setZdsz(String zdsz) {
        this.zdsz = zdsz;
    }

    public String getQsrq() {
        return qsrq;
    }

    public void setQsrq(String qsrq) {
        this.qsrq = qsrq;
    }

    public String getZzrq() {
        return zzrq;
    }

    public void setZzrq(String zzrq) {
        this.zzrq = zzrq;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public Double getTdjg() {
        return tdjg;
    }

    public void setTdjg(Double tdjg) {
        this.tdjg = tdjg;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }


}

==> estateplat-common-1.2.4-20211009.005316-904-sources.jar: cn/gtmap/estateplat/model/server/core/GdTd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 *过渡期土地登记信息表
 * @author lst
 * @version V1.0, 15-3-23
 */
@Table(name = "gd_td")
public class GdTd implements Serializable, InsertVo {
    @Id
    private String tdid;//主键
    private String djh;//地籍号
    private String zl;//土地坐落
    private Double zdmj;//宗地面积
    private String yt;//用途
    private String qsxz;//权属性质
    private String syqlx;//使用权类型
    private String qlsdfs;//权利设定方式
    private Double rjl;//容积率
    private Double jzmj;//建筑密度
    private Double jzxg;//建筑限高
    private String zdsz;//宗地四至
	private String gyqk;//共有情况
    private Double qdjg;//取得价格
    private String dwdm;//单位代码
    private Double tdjg;//土地价格
    private String dw;//单位
    private String sjly;//数据来源
    private String ldjh;//老地籍号
    private String qsrq;//起始日期
    private String zzrq;//终止日期

	private Date gxrq;
	private String xgzd;

	public String getSjly() {
		return sjly;
	}

	public void setSjly(String sjly) {
		this.sjly = sjly;
	}

	public String getLdjh() {
		return ldjh;
	}

	public void setLdjh(String ldjh) {
		this.ldjh = ldjh;
	}

	public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}

	public String getTdid() {
        return tdid;
    }

    public void setTdid(String tdid) {
        this.tdid = tdid;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getSyqlx() {
        return syqlx;
    }

    public void setSyqlx(String syqlx) {
        this.syqlx = syqlx;
    }

    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    public Double getRjl() {
        return rjl;
    }

    public void setRjl(Double rjl) {
        this.rjl = rjl;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getJzxg() {
        return jzxg;
    }

    public void setJzxg(Double jzxg) {
        this.jzxg = jzxg;
    }

    public String getZdsz() {
        return zdsz;
    }

    public void setZdsz(String zdsz) {
        this.zdsz = zdsz;
    }

    public String getQsrq() {
        return qsrq;
    }

    public void setQsrq(String qsrq) {
        this.qsrq = qsrq;
    }

    public String getZzrq() {
        return zzrq;
    }

    public void setZzrq(String zzrq) {
        this.zzrq = zzrq;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public Double getTdjg() {
        return tdjg;
    }

    public void setTdjg(Double tdjg) {
        this.tdjg = tdjg;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }


    public String getXgzd() {
        return xgzd;
    }

    public void setXgzd(String xgzd) {
        this.xgzd = xgzd;
    }
}
